@@ -33,7 +33,6 @@
 #include <gpe/errorbox.h>
 #include <gpe/spacing.h>
 #include <gpe/pixmaps.h>
-#include <gpe/render.h>
 
 #include "battery.h"
 #include "storage.h"
@@ -88,7 +87,7 @@ void init_device()
 	};
 	
 	/* then check if we have apm support available*/
-	if (!access(PROC_APM,R_OK))
+	if (!access(PROC_APM, R_OK))
 		file_apm = fopen(PROC_APM,"r");
 }
 
@@ -105,7 +104,7 @@ gint update_bat_values(gpointer data)
 	parse_file(PROC_BATTERY," Is learning? %*s %s",tmp);
 	if (strstr(tmp,"yes"))
 		islearning = TRUE;
-	
+#warning TODO: Switch to modern proc interface.	
 	if (ioctl(TSfd, GET_BATTERY_STATUS, &battery_val) == 0)
 	{
 		if (battery_val.battery_count < 2) {
@@ -269,8 +268,7 @@ gint update_bat_values(gpointer data)
 		
 		/* read data from proc entry */
 		fclose(file_apm);
-		file_apm = fopen(PROC_APM,"r");
-
+		file_apm = fopen(PROC_APM, "r");
 		if (fscanf(file_apm,
 			       "%*f %*f %*s 0x%x 0x%x 0x%x %i%% %i %4s",
 		           &ac_connected,
@@ -319,7 +317,10 @@ gint update_bat_values(gpointer data)
 					break;
 				}
 			}
-			
+		
+            if (percent > 100) percent=100;
+            if (percent < 0 )  percent=0;
+
 			gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (batt_int.bar),
 			                               (float)percent/100.0);
 			toolbar_set_style (batt_int.bar, barstate);
@@ -330,8 +331,10 @@ gint update_bat_values(gpointer data)
 			
 			if (ac_connected)
 				sprintf(tmp,"%s",_("AC connected"));
-			else
-				sprintf(tmp,"%s: %d min.",_("Lifetime"), remaining);
+			else if (remaining > 0)
+			     	sprintf(tmp,"%s: %d min.",_("Lifetime"), remaining);
+            	 else 
+            		sprintf(tmp,"");
 			gtk_label_set_text(GTK_LABEL(batt_int.llifetime),tmp);
 		}
 	}
