@@ -2,7 +2,7 @@
  * gpe-conf
  *
  * Copyright (C) 2002  Pierre TARDY <tardyp@free.fr>
- *               2003, 2004  Florian Boor <florian.boor@kernelconcepts.de>
+ *               2003 - 2005  Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,33 +31,33 @@
 #include "appmgr_setup.h"
 #include "screen.h"
 #include "unimplemented.h"
-#include "kbd.h"
 #include "network.h"
 #include "theme.h"
-#include "keyctl.h"
 #include "sleep.h"
 #include "ownerinfo.h"
 #include "login-setup.h"
 #include "users.h"
 #include "gpe-admin.h"
-#include "sleep/conf.h"
 #include "serial.h"
-#ifdef PACKAGETOOL		
-#include "packages.h"
-#include "keyboard.h"
-#endif
 #include "cardinfo.h"
 #include "tasks.h"
+#include "keys/keys.h"
+#include "sleep/conf.h"
 #include "sound/sound.h"
 
+#include <gdk/gdkx.h>
+
 #include <gpe/init.h>
 #include <gpe/picturebutton.h>
 #include <gpe/init.h>
 #include <gpe/pixmaps.h>
 #include <gpe/spacing.h>
+#include <gpe/infoprint.h>
 
+#define N_(_x) (_x)
 
-/* These aren't in the header files, so we prototype them here.
+/* 
+ * some prototypes
  */
 int setresuid(uid_t ruid, uid_t euid, uid_t suid);
 int setresgid(gid_t rgid, gid_t egid, gid_t sgid);
@@ -82,52 +82,42 @@ static struct {
 
 }self;
 
-GtkWidget *mainw; // for dialogs
+GtkWidget *mainw; /* for some dialogs */
 
 struct Applet applets[]=
   {
     { &Time_Build_Objects, &Time_Free_Objects, &Time_Save, &Time_Restore , 
-		"Time" ,"time" ,"Time and Date Setup",PREFIX "/share/pixmaps/gpe-config-time.png"},
-/*    { &Appmgr_Build_Objects, &Appmgr_Free_Objects, &Appmgr_Save, &Appmgr_Restore , 
-		"Appmgr" ,"appmgr", "Launcher Setup", PREFIX "/share/pixmaps/gpe-config-appmgr.png"},
-*/    { &screen_Build_Objects, &screen_Free_Objects, &screen_Save, &screen_Restore,
-		"Screen" , "screen", "Screen Setup", PREFIX "/share/pixmaps/gpe-config-screen.png"},
-    { &Kbd_Build_Objects, &Unimplemented_Free_Objects, &Kbd_Save, &Kbd_Restore ,
-		"vKeyboard" ,"kbd", "Virtual Keyboard Setup",PREFIX "/share/pixmaps/gpe-config-kbd.png"},
-    { &Keyctl_Build_Objects, &Unimplemented_Free_Objects, &Keyctl_Save, &Keyctl_Restore ,
-		"Buttons" ,"keyctl", "Button Configuration",PREFIX "/share/pixmaps/gpe-config-keyctl.png"},
+		N_("Time") ,"time" ,N_("Time and Date Setup"),PREFIX "/share/pixmaps/gpe-config-time.png"},
+    { &screen_Build_Objects, &screen_Free_Objects, &screen_Save, &screen_Restore,
+		N_("Screen") , "screen", N_("Screen Setup"), PREFIX "/share/pixmaps/gpe-config-screen.png"},
+    { &Keys_Build_Objects, &Unimplemented_Free_Objects, &Keys_Save, &Keys_Restore ,
+		N_("Keys & Buttons") ,"keys", N_("Keys and Buttons Setup"),PREFIX "/share/pixmaps/gpe-config-kbd.png"},
     { &Network_Build_Objects, &Network_Free_Objects, &Network_Save, &Network_Restore ,
-		"Network" ,"network","Network Setup",PREFIX "/share/pixmaps/gpe-config-network.png"},
+		N_("Network") ,"network",N_("Network Setup"),PREFIX "/share/pixmaps/gpe-config-network.png"},
     { &Theme_Build_Objects, &Unimplemented_Free_Objects, &Theme_Save, &Theme_Restore ,
-		"Theme" ,"theme", "Look and Feel",PREFIX "/share/pixmaps/gpe-config-theme.png"},
+		N_("Theme") ,"theme", N_("Look and Feel"),PREFIX "/share/pixmaps/gpe-config-theme.png"},
     { &Sleep_Build_Objects, &Unimplemented_Free_Objects, &Sleep_Save, &Sleep_Restore ,
-		"Sleep" ,"sleep","Sleep Configuration",PREFIX "/share/pixmaps/gpe-config-sleep.png"},
+		N_("Power") ,"sleep",N_("Power safe Configuration"),PREFIX "/share/pixmaps/gpe-config-sleep.png"},
     { &Ownerinfo_Build_Objects, &Ownerinfo_Free_Objects, &Ownerinfo_Save, &Ownerinfo_Restore,
-		"Owner", "ownerinfo", "Owner Information",PREFIX "/share/pixmaps/gpe-config-ownerinfo.png"},
+		N_("Owner"), "ownerinfo", N_("Owner Information"),PREFIX "/share/pixmaps/gpe-config-ownerinfo.png"},
     { &Login_Setup_Build_Objects, &Login_Setup_Free_Objects, &Login_Setup_Save, &Login_Setup_Restore,
-		"Login", "login-setup", "Login Setup",PREFIX "/share/pixmaps/gpe-config-login-setup.png"},
+		N_("Login"), "login-setup", N_("Login Setup"),PREFIX "/share/pixmaps/gpe-config-login-setup.png"},
     { &Users_Build_Objects, &Users_Free_Objects, &Users_Save, &Users_Restore ,
-		"Users" ,"users","User Administration",PREFIX "/share/pixmaps/gpe-config-users.png"},
+		N_("Users"),"users" ,N_("User Administration"),PREFIX "/share/pixmaps/gpe-config-users.png"},
     { &GpeAdmin_Build_Objects, &GpeAdmin_Free_Objects, &GpeAdmin_Save, &GpeAdmin_Restore , 
-		"GPE" ,"admin","GPE Conf Administration",PREFIX "/share/pixmaps/gpe-config-admin.png"},
+		N_("GPE") ,"admin",N_("GPE Conf Administration"),PREFIX "/share/pixmaps/gpe-config-admin.png"},
     { &Serial_Build_Objects, &Serial_Free_Objects, &Serial_Save, &Serial_Restore ,
-		"Serial" ,"serial","Serial Port Configuration",PREFIX "/share/pixmaps/gpe-config-serial.png"},
+		N_("Serial Ports") ,"serial", N_("Serial Port Configuration"),PREFIX "/share/pixmaps/gpe-config-serial.png"},
     { &Cardinfo_Build_Objects, &Cardinfo_Free_Objects, &Unimplemented_Save, &Cardinfo_Restore ,
-		"Cardinfo" ,"cardinfo","PC/CF Card Info and Config",PREFIX "/share/pixmaps/gpe-config-cardinfo.png"},
+		N_("PCMCIA/CF Cards") ,"cardinfo", N_("PCMCIA/CF Card Info and Config"),PREFIX "/share/pixmaps/gpe-config-cardinfo.png"},
     { &Sound_Build_Objects, &Sound_Free_Objects, &Sound_Save, &Sound_Restore , 
-		"Sound" ,"sound","Sound Setup",PREFIX "/share/pixmaps/gpe-config-sound.png"},
-#ifdef PACKAGETOOL		
-    { &Packages_Build_Objects, &Packages_Free_Objects, &Unimplemented_Save, &Packages_Restore ,
-		"Packages" ,"packages","Add and Remove packages",PREFIX "/share/pixmaps/gpe-config-packages.png"},
-    { &Keyboard_Build_Objects, &Unimplemented_Free_Objects, &Keyboard_Save, &Keyboard_Restore ,
-		"Keyboard" ,"keyboard", "External Keyboard Setup",PREFIX "/share/pixmaps/gpe-config-keyboard.png"},
-#endif		
+		N_("Sound") ,"sound", N_("Sound Setup"), PREFIX "/share/pixmaps/gpe-config-sound.png"},
     { &Unimplemented_Build_Objects, &Unimplemented_Free_Objects, &Unimplemented_Save, &Unimplemented_Restore ,
-		"Task nameserver" ,"task_nameserver","Task for changing nameserver", PREFIX "/share/pixmaps/gpe-config-admin.png"},
+		N_("Task nameserver") ,"task_nameserver", N_("Task for changing nameserver"), PREFIX "/share/pixmaps/gpe-config-admin.png"},
     { &Unimplemented_Build_Objects, &Unimplemented_Free_Objects, &Unimplemented_Save, &Unimplemented_Restore ,
-		"Task sound" ,"task_sound","Command line task saving/restoring sound settings.", PREFIX "/share/pixmaps/gpe-config-admin.png"},
+		N_("Task sound") ,"task_sound", N_("Command line task saving/restoring sound settings."), PREFIX "/share/pixmaps/gpe-config-admin.png"},
     { &Unimplemented_Build_Objects, &Unimplemented_Free_Objects, &Unimplemented_Save, &Unimplemented_Restore ,
-		"Task background image" ,"task_background","Only select background image.", PREFIX "/share/pixmaps/gpe-config-admin.png"}
+		N_("Task background image") ,"task_background", N_("Only select background image."), PREFIX "/share/pixmaps/gpe-config-admin.png"}
   };
   
 struct gpe_icon my_icons[] = {
@@ -153,22 +143,32 @@ int applets_nb = sizeof(applets) / sizeof(struct Applet);
 
 void Save_Callback()
 {
+  gpe_popup_infoprint(GDK_DISPLAY(), _("Settings saved"));
+  while (gtk_events_pending())
+	  gtk_main_iteration_do(FALSE);
   applets[self.cur_applet].Save();
+  gtk_widget_hide(self.w);
+  sleep(1);
   if(self.alone_applet)
   {
     gtk_main_quit();
-    gtk_exit(0);
+    exit(0);
   }
 }
 
 
 void Restore_Callback()
 {
+  gpe_popup_infoprint(GDK_DISPLAY(), _("Aborted"));
+  while (gtk_events_pending())
+	  gtk_main_iteration_do(FALSE);
   applets[self.cur_applet].Restore();
+  gtk_widget_hide(self.w);
+  sleep(1);
   if(self.alone_applet)
   {
     gtk_main_quit();
-    gtk_exit(0);
+    exit(0);
   }
 }
 
@@ -248,10 +248,10 @@ void initwindow()
    self.w = mainw = gtk_window_new(GTK_WINDOW_TOPLEVEL);
    gtk_widget_set_usize(GTK_WIDGET(self.w),240, 310);
 	
-   if ((size_x > 640) && (size_y > 480))
+   if ((size_x >= 640) && (size_y >= 480))
    {
       gtk_window_set_type_hint(GTK_WINDOW(self.w), GDK_WINDOW_TYPE_HINT_DIALOG);
-	  gtk_window_set_default_size(GTK_WINDOW(self.w), 280, 340);
+	  gtk_window_set_default_size(GTK_WINDOW(self.w), 320, 420);
    }
    
    wstyle = self.w->style;
@@ -326,7 +326,7 @@ void main_one(int argc, char **argv,int applet)
   /* check if we are called to do a command line task */
   if (argc > 2)
   {
-	  if (!strcmp(argv[1],"task_nameserver"))
+	  if (!strcmp(argv[1], "task_nameserver"))
 	  {
 		  handled = TRUE;
 		  if (argc == 3)
@@ -442,11 +442,11 @@ int main(int argc, char **argv)
       suidout = fdopen(pipe2[1],"w");
       suidin = fdopen(pipe1[0],"r");
 
-      setresuid(getuid(),getuid(),getuid()); // abandon privilege..
-      setresgid(getgid(),getgid(),getgid()); // abandon privilege..
+      setresuid(getuid(), getuid(), getuid()); // abandon privilege..
+      setresgid(getgid(), getgid(), getgid()); // abandon privilege..
 	
-	signal(SIGINT,Restore_Callback);
-	signal(SIGTERM,Restore_Callback);
+	signal(SIGINT, Restore_Callback);
+	signal(SIGTERM, Restore_Callback);
 	
       if(argc == 1)
 	{
