@@ -48,7 +48,6 @@
 #include <gpe/errorbox.h>
 #include <gpe/spacing.h>
 #include <gpe/picturebutton.h>
-#include <gpe/render.h>
 #include <gpe/question.h>
 #include <gpe/smallbox.h>
 #include <gpe/gtksimplemenu.h>
@@ -65,7 +64,6 @@ GtkWidget *create_nwstatic_widgets (NWInterface_t iface);
 GtkWidget *create_nwdhcp_widgets (NWInterface_t iface);
 GtkWidget *create_nwppp_widgets (NWInterface_t iface);
 
-static guint not_added = 0;
 static gchar *cfgfile;
 static gboolean have_access = FALSE;
 static GtkTooltips *tooltips;
@@ -300,12 +298,15 @@ add_interface (GtkWidget * widget, gpointer d)
 		if (ctable)
 		{
 			label = gtk_label_new (iflist[i].name);
-			gtk_notebook_append_page (GTK_NOTEBOOK (table),
-						  GTK_WIDGET (ctable), label);
+			iflist[i].uipos = gtk_notebook_append_page (GTK_NOTEBOOK (table),
+			                                            GTK_WIDGET (ctable),
+			                                            label);
 			gtk_widget_show_all (table);
+			g_object_set_data(G_OBJECT(ctable), "ifnr", (gpointer)i);
 		}
 		else
-			not_added++;
+			iflist[i].uipos = -1;
+		
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (table), -1);
 	}
 }
@@ -319,6 +320,8 @@ remove_interface (GtkWidget * widget, gpointer d)
 	page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (table),
 					  gtk_notebook_get_current_page
 					  (GTK_NOTEBOOK (table)));
+	if (!page) 
+		return;
 	ifname = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (table), page);
 	if (gpe_question_ask
 	    (_("Do you want to delete this interface?"), _("Question"),
@@ -335,11 +338,13 @@ remove_interface (GtkWidget * widget, gpointer d)
 void
 changed_nwtype (GtkToggleButton * togglebutton, gpointer user_data)
 {
-	GtkWidget *ctable, *label;
+	GtkWidget *ctable, *label, *page;
 	gchar wname[100];
-	gint row =
-		gtk_notebook_get_current_page (GTK_NOTEBOOK (table)) +
-		not_added - PAGE_OFFSET;
+	gint row;
+	
+	page = gtk_notebook_get_nth_page(GTK_NOTEBOOK (table), 
+	                                 gtk_notebook_get_current_page (GTK_NOTEBOOK (table)));
+	row = (gint)g_object_get_data(G_OBJECT(page), "ifnr");
 
 	if (!gtk_toggle_button_get_active (togglebutton))
 		return;		// just run once
@@ -385,10 +390,11 @@ changed_nwtype (GtkToggleButton * togglebutton, gpointer user_data)
 					  (GTK_NOTEBOOK (table)));
 		gtk_notebook_insert_page (GTK_NOTEBOOK (table),
 					  GTK_WIDGET (ctable), label,
-					  row - not_added + PAGE_OFFSET);
+					  iflist[row].uipos);
 		gtk_widget_show_all (table);
 		gtk_notebook_set_page (GTK_NOTEBOOK (table),
-				       row - not_added + PAGE_OFFSET);
+				      iflist[row].uipos);
+		g_object_set_data(G_OBJECT(ctable), "ifnr", (gpointer)row);
 	}
 }
 
@@ -453,7 +459,7 @@ create_editable_entry_simple (GtkWidget * attach_to, gchar * name,
 		gtk_entry_set_text (GTK_ENTRY (label), wdata);
 	gtk_entry_set_editable (GTK_ENTRY (label), TRUE);
 	gtk_table_attach (GTK_TABLE (attach_to), label, 1, 2, clnr, clnr + 1,
-			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
 			  (GtkAttachOptions) (GTK_FILL),
 			  gpe_boxspacing, gpe_boxspacing);
 }
@@ -563,7 +569,7 @@ show_wificonfig(GtkWidget *window, NWInterface_t *iface)
 	guint gpe_boxspacing = gpe_get_boxspacing ();
 	guint gpe_border = gpe_get_border ();
 
-	gchar *tmpval;
+	gchar *tmpval1, *tmpval2;
 	gint response;
 	char  tmp_key[256];
 	
@@ -597,9 +603,12 @@ show_wificonfig(GtkWidget *window, NWInterface_t *iface)
 
 	label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	tmpval = g_strdup_printf (_("<b>WiFi config for %s</b>"),iface->name);
-	gtk_label_set_markup (GTK_LABEL (label), tmpval);
-	g_free (tmpval);
+
+	tmpval1 = g_strdup_printf (_("WiFi config for %s"), iface->name);
+	tmpval2 = g_strdup_printf ("<b>%s</b>", tmpval1);
+	gtk_label_set_markup (GTK_LABEL (label), tmpval2);
+	g_free (tmpval1);
+  g_free (tmpval2);
 	gtk_table_attach (GTK_TABLE (ctable), label, 0, 2, 0, 1,
 			  (GtkAttachOptions) (GTK_FILL),
 			  (GtkAttachOptions) (GTK_FILL),
@@ -922,12 +931,14 @@ show_wificonfig(GtkWidget *window, NWInterface_t *iface)
 void
 changed_wifi (GtkToggleButton * togglebutton, gpointer user_data)
 {
-	GtkWidget *widget;
+	GtkWidget *widget, *page;
 	gchar wname[100];
-	gint ifnr = gtk_notebook_get_current_page (GTK_NOTEBOOK (table)) +
-		not_added - PAGE_OFFSET;
+	gint ifnr;
+	
+	page = gtk_notebook_get_nth_page(GTK_NOTEBOOK (table), 
+	                                 gtk_notebook_get_current_page (GTK_NOTEBOOK (table)));
+	ifnr = (gint)g_object_get_data(G_OBJECT(page), "ifnr");
 
-	// look who called us...
 	strcpy (wname, "wificonfig");
 	strcat (wname, iflist[ifnr].name);
 	
@@ -941,10 +952,12 @@ changed_wifi (GtkToggleButton * togglebutton, gpointer user_data)
 void
 clicked_wificonfig (GtkButton *button, gpointer user_data)
 {
+	GtkWidget *page;
 	gint ifnr;
 	
-	ifnr = gtk_notebook_get_current_page (GTK_NOTEBOOK (table)) +
-		not_added - PAGE_OFFSET;
+	page = gtk_notebook_get_nth_page(GTK_NOTEBOOK (table), 
+	                                 gtk_notebook_get_current_page (GTK_NOTEBOOK (table)));
+	ifnr = (gint)g_object_get_data(G_OBJECT(page), "ifnr");
 
 	show_wificonfig(gtk_widget_get_toplevel(GTK_WIDGET(button)), &iflist[ifnr]);
 }
@@ -1648,22 +1661,27 @@ Network_Build_Objects ()
 	for (row = 0; row < num_int; row++)
 	{
 		ctable = NULL;
-		if (iflist[row].isstatic)
-			ctable = create_nwstatic_widgets (iflist[row]);
-		if (iflist[row].isdhcp)
-			ctable = create_nwdhcp_widgets (iflist[row]);
-		if (iflist[row].isppp)
-			ctable = create_nwppp_widgets (iflist[row]);
+		if (iflist[row].ispresent)
+		{
+			if (iflist[row].isstatic)
+				ctable = create_nwstatic_widgets (iflist[row]);
+			if (iflist[row].isdhcp)
+				ctable = create_nwdhcp_widgets (iflist[row]);
+			if (iflist[row].isppp)
+				ctable = create_nwppp_widgets (iflist[row]);
+		}
 		if (ctable)
 		{
 			if (!have_access)
 				gtk_widget_set_sensitive (ctable, FALSE);
 			label = gtk_label_new (iflist[row].name);
-			gtk_notebook_append_page (GTK_NOTEBOOK (table),
-						  GTK_WIDGET (ctable), label);
+			iflist[row].uipos = gtk_notebook_append_page (GTK_NOTEBOOK (table),
+			                                              GTK_WIDGET (ctable), 
+			                                              label);
+			g_object_set_data(G_OBJECT(ctable), "ifnr", (gpointer)row);
 		}
 		else
-			not_added++;	// we'll run into trouble if we have a loopback device between other in interfaces
+			iflist[row].uipos = -1;
 	}
 	return tablebox;
 }
