@@ -22,14 +22,10 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <gtk/gtk.h>
-#ifndef _XOPEN_SOURCE
-#define _XOPEN_SOURCE /* Pour GlibC2 */
-#endif
 #include <time.h>
 
 #include <gpe/errorbox.h>
 #include <gpe/pixmaps.h>
-#include <gpe/render.h>
 #include <gpe/spacing.h>
 
 #include "applets.h"
@@ -46,6 +42,12 @@ void File_Selected (char *file,
 
 #define UPGRADE_ERROR      -1
 #define UPGRADE_NOT_NEEDED  0
+#define GPE_LOGIN_STARTUP	"/etc/X11/Xsession.d/50autolock"
+
+#ifndef IMG_HEIGHT
+  #define IMG_HEIGHT 64
+  #define IMG_WIDTH  64
+#endif
 
 GtkWidget *photofile;
 GtkWidget *name;
@@ -59,6 +61,14 @@ static gchar *ownerphotofile, *ownername, *owneremail, *ownerphone, *owneraddres
 
 FILE *fp;
 
+
+static void
+restart_gpe_login(void)
+{
+	system("killall gpe-login");
+	system(GPE_LOGIN_STARTUP);
+}
+
 GtkWidget *Ownerinfo_Build_Objects()
 {
   GtkWidget *table, *lHeader;
@@ -316,7 +326,7 @@ GtkWidget *Ownerinfo_Build_Objects()
                     (GtkAttachOptions) (table_attach_right_col_y | GTK_EXPAND), 0, 0);
   
   /* these values are just a dummy size for the initial display */
-  photo = gpe_create_pixmap (table, ownerphotofile, 24, 32);
+  photo = gpe_create_pixmap (table, ownerphotofile, IMG_WIDTH, IMG_WIDTH);
   gtk_container_add (GTK_CONTAINER (button), photo);
 
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -391,6 +401,9 @@ void Ownerinfo_Save()
       fputs (owneraddress, fp);
       fclose (fp);
 	  suid_exec("CPOI","");
+	  /* more a hack than a feature */
+	  usleep(300000);
+	  restart_gpe_login();
     }
   else /* fp == NULL, something went wrong */
     {
@@ -564,15 +577,10 @@ void File_Selected (char *file,
 {
   /* check if we can read the selected file */
   /* FIXME: gotta check if it's a valid png file */
-  int width, height;
   if (access (file, R_OK) == 0) {
     gtk_entry_set_text (GTK_ENTRY (photofile), file);
-	width = 32;
-	height = 48;
     gtk_container_remove (GTK_CONTAINER (button), photo);
-    photo = gpe_create_pixmap (button, file,
-					 width,
-					 height);
+    photo = gpe_create_pixmap (button, file, IMG_WIDTH, IMG_HEIGHT);
     gtk_container_add (GTK_CONTAINER (button), photo);
     gtk_widget_show (GTK_WIDGET (photo));
   }
